<?xml version="1.0" encoding="UTF-8" ?>

<!--

    Sample code copyright information.
    ==================================

    (C) Copyright IBM Corp. 2002

    US Government Users Restricted Rights Use, duplication or
    disclosure restricted by GSA ADP Schedule Contract with IBM Corp.

    The program is provided "as is" without any warranty express or
    implied, including the warranty of non-infringement and the implied
    warranties of merchantibility and fitness for a particular purpose.
    IBM will not be liable for any damages suffered by you as a result
    of using the Program. In no event will IBM be liable for any
    special, indirect or consequential damages or lost profits even if
    IBM has been advised of the possibility of their occurrence. IBM
    will not be liable for any third party claims against you.

-->

<!--
    identtransform.xsl
    February 2003
    
    O. M. Atogi, D. Calhoun, M. Shields
    
    This transformation will take an XML document that represents WC data
    and substitute literal primary and foreign key values with internal
    aliases suitable for ID Resolver.
    
    Certain keys (attributes) should not be converted. The names of these
    attributes are included in the keys-to-ignore variable.
    
    Certain keys are outside the scope of the data represented in the XML
    document (e.g.: foreign keys that don't have a matching primary key
    record in the document). The names of these attributes are included in 
    the keys-to-translate variable. There should also be a parameter declared
    with the same name. Finally, an xsl:when clause should be added to the
    template to substitute the parameter value for the attribute.
    (Search for member_id below to see how this is done.)
    
    Attributes reprenting primary or foreign keys are handled on the basis
    of a naming pattern (i.e.: contains '_id'). Attributes representing keys 
    that don't match this naming pattern could be handled as special cases
    in much the same way as attributes included in the keys-to-translate list.
    
    This transformation assumes that all keys in the source document are 
    literals and none have been converted to internal aliases. 
-->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

    <!--
        Root element name.
        This value will be included in the DOCTYPE declaration
        and also used for the root element name.
        This name should match the root element name
        for the DTD file being used (see next parameter).
    -->
    <xsl:param name="rootelement" />
    
    <!--
        DTD file to include in DOCTYPE declaration.
        This could be a URL but typically is just the file name
        as the DTD file usually exists in the same directory 
        as the source file.
        
        This parameter is necessary as it is currently impossible
        to retrieve the DOCTYPE info from the source XML document
        within the context of the XSLT transform.
    -->
    <xsl:param name="dtdfile" />
    
    
    <!-- 
        List of foreign keys that should be provided explicitly.
        
        Note: each of these keys should appear as a parameter AND 
        should also be included in the keys-to-translate variable above.
        For each such key, an xsl:when element must be added to the template below.
    -->
    <xsl:param name="member_id" />
        
    
    <!--
        The following list of foreign key columns/attributes
        will not be converted to internal aliases. They will
        remain the same as they exist in the source document.
    -->
    <xsl:variable name="keys-to-ignore">vendor_id wholesalestore_id merchantstore_id calmethod_id_qfy calmethod_id_app calmethod_id taxcgry_id qtyunit_id calusage_id storeent_id ffmcenter_id language_id itemtype_id catenttype_id catreltype_id attrtype_id devicefmt_id mbrgrp_id catenttype_id operator_id storegrp_id rtnffmctr_id massoc_id massoctype_id</xsl:variable>
    
    <!--
        The following list of foreign key columns/attributes
        will not be converted to internal aliases. These keys will
        be "translated" to some other value (typically a parameter,
        although it could be hard-coded). These keys will be handled
        individually in the template below (see the example for 
        member_id, below).
    -->
    <xsl:variable name="keys-to-translate"></xsl:variable>
    
    
    <xsl:output indent="yes" method="xml"/>
    
    <!--
        Root template
    -->
    <xsl:template match= "/" >
    
        <!-- create DOCTYPE declaration -->
        <xsl:text disable-output-escaping="yes">&#10;&lt;!DOCTYPE </xsl:text><xsl:value-of select="$rootelement"/><xsl:text> SYSTEM &quot;</xsl:text><xsl:value-of select="$dtdfile"/><xsl:text disable-output-escaping="yes">&quot;&gt;&#10;&#10;</xsl:text>
        
        <!-- create a comment noting the parameters passed in -->
        <xsl:comment>
        This import file was processed with the following parameters:
        
          rootelement  = &quot;<xsl:value-of select="$rootelement" />&quot;
          dtdfile      = &quot;<xsl:value-of select="$dtdfile" />&quot;
          member_id    = &quot;<xsl:value-of select="$member_id" />&quot;&#10;</xsl:comment>
        <xsl:text>&#10;&#10;</xsl:text>
        
        <xsl:element name="{$rootelement}">
            <xsl:apply-templates select="/*/*"/>
        </xsl:element>
    </xsl:template>

    <!-- 
        Template for all other elements
        
        Note: elements are assumed to be empty
    -->
    <xsl:template match="*">
        <xsl:copy>
            <xsl:for-each select="@*">
                <xsl:choose>
                    <!-- if attribute in list to translate -->
                    <xsl:when test="contains($keys-to-translate,local-name())">
                        <xsl:attribute name="{local-name()}">
                            <xsl:choose>
                                <xsl:when test="local-name()='member_id' and string-length($member_id)!=0"><xsl:value-of select="$member_id"/></xsl:when>
                                <xsl:otherwise><xsl:value-of select="."/></xsl:otherwise>
                            </xsl:choose>
                        </xsl:attribute>
                    </xsl:when>
                    
                    <!-- attribute ends with '_id' but is not in the list to ignore -->
                    <xsl:when test="contains(local-name(),'_id') and string-length(substring-after(local-name(),'_id'))=0 and not (contains($keys-to-ignore,local-name())) and not (.='0' or string-length(.)=0)">
                        <xsl:attribute name="{local-name()}">
                            <xsl:value-of select="concat('@',concat(local-name(),concat('_',.)))" />
                        </xsl:attribute>
                    </xsl:when>
                    
                    <!-- attribute has '_id_' in the middle, but is not in the list to ignore -->
                    <xsl:when test="contains(local-name(),'_id_') and not (contains($keys-to-ignore,local-name())) and not (.='0' or string-length(.)=0)">
                        <xsl:variable name="prefix" select="substring-before(local-name(),substring-after(local-name(),'_id_'))" />
                        <xsl:attribute name="{local-name()}">
                            <xsl:value-of select="concat('@',concat($prefix,.))" />
                        </xsl:attribute>
                    </xsl:when>
                    
                    <xsl:otherwise>
                        <xsl:copy-of select="." />
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:for-each>
        </xsl:copy>
    </xsl:template>
        
</xsl:stylesheet>
