<?xml version="1.0" encoding="UTF-8" ?>

<!--

    Sample code copyright information.
    ==================================

    (C) Copyright IBM Corp. 2002

    US Government Users Restricted Rights Use, duplication or
    disclosure restricted by GSA ADP Schedule Contract with IBM Corp.

    The program is provided "as is" without any warranty express or
    implied, including the warranty of non-infringement and the implied
    warranties of merchantibility and fitness for a particular purpose.
    IBM will not be liable for any damages suffered by you as a result
    of using the Program. In no event will IBM be liable for any
    special, indirect or consequential damages or lost profits even if
    IBM has been advised of the possibility of their occurrence. IBM
    will not be liable for any third party claims against you.

-->

<!--
    membertransform.xsl
    September 2003
    @author M. Shields
    
    This XSL Style Sheet will not replace the out-of-the-box identtransform.xsl.
    Therefore, this XSL Style Sheet will run after identtransform.xsl has been run.
-->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

    <!--
        Root element name.
        This value will be included in the DOCTYPE declaration
        and also used for the root element name.
        This name should match the root element name
        for the DTD file being used (see next parameter).
    -->
    <xsl:param name="rootelement" />
    
    <!--
        DTD file to include in DOCTYPE declaration.
        This could be a URL but typically is just the file name
        as the DTD file usually exists in the same directory 
        as the source file.
        
        This parameter is necessary as it is currently impossible
        to retrieve the DOCTYPE info from the source XML document
        within the context of the XSLT transform.
    -->
    <xsl:param name="dtdfile" />
    
    
    <!-- 
        List of foreign keys that should be provided explicitly.
        
        Note: each of these keys should appear as a parameter AND 
        should also be included in the keys-to-translate variable above.
        For each such key, an xsl:when element must be added to the template below.
    -->
    <xsl:param name="member_id" />
        
    <!--
        Parameters
    -->
    <xsl:param name="tmpmember_id">member_id</xsl:param>
    <xsl:param name="tmpstate">1</xsl:param>
    <xsl:param name="tmporgtype">O</xsl:param>
    <xsl:param name="tmpusertype">U</xsl:param>
    
    
    <xsl:output indent="yes" method="xml"/>
    
    <!--
        Root template
    -->
    <xsl:template match= "/" >
    
        <!-- create DOCTYPE declaration -->
        <xsl:text disable-output-escaping="yes">&#10;&lt;!DOCTYPE </xsl:text><xsl:value-of select="$rootelement"/><xsl:text> SYSTEM &quot;</xsl:text><xsl:value-of select="$dtdfile"/><xsl:text disable-output-escaping="yes">&quot;&gt;&#10;&#10;</xsl:text>
        
        <!-- create a comment noting the parameters passed in -->
        <xsl:comment>
        This import file was processed with the following parameters:
        
          rootelement  = &quot;<xsl:value-of select="$rootelement" />&quot;
          dtdfile      = &quot;<xsl:value-of select="$dtdfile" />&quot;
          member_id    = &quot;<xsl:value-of select="$member_id" />&quot;&#10;</xsl:comment>
        <xsl:text>&#10;&#10;</xsl:text>
        
        <xsl:element name="{$rootelement}">
            <xsl:apply-templates select="orgentity"/>
            <xsl:apply-templates select="/*/*"/>
        </xsl:element>
    </xsl:template>

    <!-- 
        Template for all other elements
        
        Note: elements are assumed to be empty
    -->
    
    <xsl:template name="search-replace">
    <xsl:param name="text"/>
    <xsl:param name="replace"/>
    <xsl:param name="with"/>
    <xsl:choose>
      <xsl:when test="contains($text,$replace)">
        <xsl:value-of select="substring-before($text,$replace)"/>
        <xsl:value-of select="$with"/>
        <xsl:call-template name="search-replace">
          <xsl:with-param name="text" select="substring-after($text,$replace)"/>
          <xsl:with-param name="replace" select="$replace"/>
          <xsl:with-param name="with" select="$with"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$text"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

    <xsl:template match="orgentity">
        <xsl:copy>
            <xsl:for-each select="@*">
                <xsl:choose>
                    <!-- if attribute in list to translate -->
                    <xsl:otherwise>
                        <xsl:copy-of select="." />
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:for-each>
        	<xsl:element name="ISA">
        	  <xsl:element name="member">
				    <xsl:variable name="elementReplaced">
				      <xsl:call-template name="search-replace">
				        <xsl:with-param name="text" select="@orgentity_id"/>
				        <xsl:with-param name="replace" select="'orgentity'"/>
				        <xsl:with-param name="with" select="'member'"/>
				      </xsl:call-template>
				    </xsl:variable>
        	  		<xsl:attribute name="member_id"><xsl:value-of select="$elementReplaced"/></xsl:attribute>
        	  		<xsl:attribute name="type"><xsl:value-of select="$tmporgtype" /></xsl:attribute>
        	  		<xsl:attribute name="state"><xsl:value-of select="$tmpstate" /></xsl:attribute>
        	  </xsl:element>
        	</xsl:element>
        </xsl:copy>
    </xsl:template>
    <xsl:template match="users">
        <xsl:copy>
            <xsl:for-each select="@*">
                <xsl:copy-of select="." />
            </xsl:for-each>
        	<xsl:element name="ISA">
        	  <xsl:element name="member">
				    <xsl:variable name="elementReplaced">
				      <xsl:call-template name="search-replace">
				        <xsl:with-param name="text" select="@users_id"/>
				        <xsl:with-param name="replace" select="'users'"/>
				        <xsl:with-param name="with" select="'member'"/>
				      </xsl:call-template>
				    </xsl:variable>
        	  		<xsl:attribute name="member_id"><xsl:value-of select="$elementReplaced"/></xsl:attribute>
        	  		<xsl:attribute name="type"><xsl:value-of select="$tmpusertype" /></xsl:attribute>
        	  		<xsl:attribute name="state"><xsl:value-of select="$tmpstate" /></xsl:attribute>
        	  </xsl:element>
        	</xsl:element>
        </xsl:copy>
    </xsl:template>
    
    <xsl:template match="mbrrel">
        <xsl:copy>
            <xsl:for-each select="@*">
                <xsl:choose>
                    
                    <!-- attribute has '_id_' in the middle, but is not in the list to ignore -->
                    <xsl:when test="local-name()='descendant_id'">
			    <xsl:variable name="elementReplaced">
			      <xsl:call-template name="search-replace">
			        <xsl:with-param name="text" select="."/>
			        <xsl:with-param name="replace" select="'descendant'"/>
			        <xsl:with-param name="with" select="'member'"/>
			      </xsl:call-template>
			    </xsl:variable>
                        <xsl:attribute name="{local-name()}">
                            <xsl:value-of select="$elementReplaced"/>
                        </xsl:attribute>
                    </xsl:when>
                    <xsl:when test="local-name()='ancestor_id'">
			    <xsl:variable name="elementReplaced">
			      <xsl:call-template name="search-replace">
			        <xsl:with-param name="text" select="."/>
			        <xsl:with-param name="replace" select="'ancestor'"/>
			        <xsl:with-param name="with" select="'member'"/>
			      </xsl:call-template>
			    </xsl:variable>
                        <xsl:attribute name="{local-name()}">
                            <xsl:value-of select="$elementReplaced"/>
                        </xsl:attribute>
                    </xsl:when>
                    
                    <xsl:otherwise>
                        <xsl:copy-of select="." />
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:for-each>
        </xsl:copy>
    </xsl:template>
    <xsl:template match="busprof">
        <xsl:copy>
            <xsl:for-each select="@*">
                <xsl:choose>
                    
                    <!-- attribute has '_id_' in the middle, but is not in the list to ignore -->
                    <xsl:when test="local-name()='org_id'">
			    <xsl:variable name="elementReplaced">
			      <xsl:call-template name="search-replace">
			        <xsl:with-param name="text" select="."/>
			        <xsl:with-param name="replace" select="'org'"/>
			        <xsl:with-param name="with" select="'orgentity'"/>
			      </xsl:call-template>
			    </xsl:variable>
                        <xsl:attribute name="{local-name()}">
                            <xsl:value-of select="$elementReplaced"/>
                        </xsl:attribute>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:copy-of select="." />
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:for-each>
        </xsl:copy>
    </xsl:template>
    <xsl:template match="userreg">
        <xsl:copy>
            <xsl:for-each select="@*">
                <xsl:choose>
                    
                    <!-- attribute has '_id_' in the middle, but is not in the list to ignore -->
                    <xsl:when test="local-name()='plcyacct_id'">
			    <xsl:variable name="elementReplaced">
			      <xsl:call-template name="search-replace">
			        <xsl:with-param name="text" select="."/>
			        <xsl:with-param name="replace" select="'@plcyacct_id_'"/>
			        <xsl:with-param name="with" select="''"/>
			      </xsl:call-template>
			    </xsl:variable>
                        <xsl:attribute name="{local-name()}">
                            <xsl:value-of select="$elementReplaced"/>
                        </xsl:attribute>
                    </xsl:when>
                    <xsl:when test="local-name()='logonpassword'">
                        <xsl:attribute name="{local-name()}">
                            
                        </xsl:attribute>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:copy-of select="." />
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:for-each>
        </xsl:copy>
    </xsl:template>
    <xsl:template match="mbrrole">
        <xsl:copy>
            <xsl:for-each select="@*">
                <xsl:choose>
                    
                    <!-- attribute has '_id_' in the middle, but is not in the list to ignore -->
                    <xsl:when test="local-name()='role_id'">
			    <xsl:variable name="elementReplaced">
			      <xsl:call-template name="search-replace">
			        <xsl:with-param name="text" select="."/>
			        <xsl:with-param name="replace" select="'@role_id_'"/>
			        <xsl:with-param name="with" select="''"/>
			      </xsl:call-template>
			    </xsl:variable>
                        <xsl:attribute name="{local-name()}">
                            <xsl:value-of select="$elementReplaced"/>
                        </xsl:attribute>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:copy-of select="." />
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:for-each>
        </xsl:copy>
    </xsl:template>
    <xsl:template match="*">
        <xsl:copy>
            <xsl:for-each select="@*">
            	<xsl:copy-of select="." />
            </xsl:for-each>
        </xsl:copy>
    </xsl:template>
        
</xsl:stylesheet>
